import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='smartninja-mongo',
    url='https://github.com/smartninja/smartninja-mongo',
    author='Matej Ramuta',
    author_email='matej.ramuta@gmail.com',
    packages=['smartninja_mongo'],
    install_requires=["tinymongo", "pymongo"],
    version='0.2',
    license='MIT',
    description='SmartNinja Mongo - a simple MongoDB & TinyDB wrapper.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



import os

if os.environ.get("DYNO") or os.environ.get("APPSETTING_WEBSITE_SITE_NAME") or os.environ.get("CUSTOM_MONGO_SERVER"):
    # if Heroku (DYNO), Azure (APPSETTING_WEBSITE_SITE_NAME) or custom env variable (CUSTOM_MONGO_SERVER)
    from pymongo import MongoClient as RealMongoClient

    class MongoClient(RealMongoClient):
        pass
else:
    from tinymongo import TinyMongoClient

    class MongoClient(TinyMongoClient):
        def __init__(self, host=None, port=None, document_class=dict, tz_aware=None, connect=None, **kwargs):
            if not host or "://" in host:  # if it's URL
                host = "localhost.db"

            super().__init__(foldername=host)
